{pkgs, ...}: {
  home.packages = with pkgs; [
    helix
    firefox-devedition
    git
    alacritty
    eww-wayland
    pinentry
    rofi-wayland
    acpi
    sops
  ];

  programs.bash.enable = true;
  programs.swaylock.enable = true;

  programs.waybar = {
    enable = true;

    settings.mainbar = {
      layer = "top";
      position = "top";
      height = 30;

      modules-left = ["hyprland/workspaces"];
      modules-right = ["pulseaudio" "network" "cpu" "memory" "temperature" "battery" "clock" "tray"];
    };
  };

  programs.helix = {
    enable = true;
    defaultEditor = true;

    settings = {
      theme = "onedark";

      editor = {
        line-number = "relative";
        true-color = true;
        gutters = ["diagnostics" "spacer" "line-numbers" "spacer" "diff"];
        cursorline = true;
        completion-trigger-len = 2;

        cursor-shape = {
          insert = "bar";
          normal = "block";
          select = "underline";
        };

        lsp = {
          display-messages = true;
          display-inlay-hints = true;
        };

        statusline = {
          left = ["mode" "spinner"];
          center = ["file-name"];
          right = ["diagnostics" "selections" "position" "file-encoding" "file-line-ending" "file-type" "version-control"];

          mode = {
            normal = "NORMAL";
            insert = "INSERT";
            select = "SELECT";
          };
        };
      };
    };
  };

  programs.thunderbird = {
    enable = true;
    profiles = {
      main = {
        isDefault = true;
        withExternalGnupg = true;
      };
    };
  };

  accounts.email.accounts = {
    patrick = {
      primary = true;
      realName = "Patrick Michl";
      address = "me@fuckwit.dev";
      userName = "me@fuckwit.dev";
      gpg = {
        key = "5FA64909521A5C85992F26E0F819AEFF941BB849";
        signByDefault = true;
      };
      imap = {
        host = "mail.fuckwit.dev";
        port = 143;
        tls = {
          useStartTls = true;
        };
      };
      smtp = {
        host = "mail.fuckwit.dev";
        port = 587;
        tls = {
          useStartTls = true;
        };
      };
      thunderbird = {
        enable = true;
        profiles = ["main"];
      };
    };
  };

  home.stateVersion = "23.11";
}
